@@ -8,7 +8,6 @@ import logging
 import traceback
 import cgitb
 import uuid
-import chardet
 import pytils
 cgitb.enable(format='text')
 
@@ -37,7 +36,6 @@ from annoying.functions import get_object_or_None
 # Django:
 from django.shortcuts import _get_queryset
 from django.contrib.auth.models import User
-from django.core.files import File
 from django.core.files.base import ContentFile
 
 # Local:
@@ -203,6 +201,8 @@ def save_email_object(raw_email, send_email=False):
     email_obj = EmailLog.objects.create(
         sender=msg['From'],
         recipient=msg['To'],
+        cc=msg['CC'],
+        bcc=msg['BCC'],
         subject=msg['Subject'],
         raw_body=dest_document_body,
         message_id=msg['Message-ID'] or "",
@@ -220,9 +220,6 @@ def save_email_object(raw_email, send_email=False):
         email_attach = EmailAttachment(email_log=email_obj)
         email_attach.attachment.save(file_name, ContentFile(content))
 
-    orig_from = msg['From']
-    orig_to = msg['To']
-
     if ',' in email_obj.recipient:
         # TODO few recipients not implemented
         recipients = email_obj.recipient.split(',')
